==> sf-0.1.tar.gz: sf-0.1/src/sf_kernel.h <==
/*  ----------------------------------------------------------------------
    sf Firewall Software -- a TCP/IP packet filter for Linux
    Copyright (C) 1996 Robert Muchsel and Roland Schmid

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Please address all correspondence concerning the software to 
    firewall-bugs@switch.ch.
    ----------------------------------------------------------------------  */

/*
 * This file contains all definitions and exported symbols for
 * the sf firewall kernel patches.
 *
 * $Id: sf_kernel.h,v 1.13 1995/07/13 14:37:44 roland Rel $
 */

#ifndef _SF_KERNEL_H
#define _SF_KERNEL_H

#define SF_RC_ACCEPT    1    /* accept packet */
#define SF_RC_BLOCK     0    /* drop packet */

/*
 *	Which ip routine is calling?
 */

#define SF_STATE_RECEIVE  0
#define SF_STATE_FORWARD  1
#define SF_STATE_TRANSMIT 2

/* macro to convert the return code into the icmp_message_type to be sent */
#define RC_TO_ICMPTYPE(a)	(abs( (a) ) - 1)

/*
 *	Exported kernel symbols
 */

extern int sf_fw_chk_pass(struct iphdr *, struct device *, int);
extern int sf_fw_chk_block(struct iphdr *, struct device *, int);
extern int (*sf_fw_chk)(struct iphdr *, struct device *, int);

#endif

==> sf-0.2.9.tar.gz: sf-0.2.9/src/sf_kernel.h <==
/*  ----------------------------------------------------------------------
    sf Firewall Software -- a TCP/IP packet filter for Linux
    Copyright (C) 1996 Robert Muchsel and Roland Schmid

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    Please address all correspondence concerning the software to 
    firewall-bugs@switch.ch.
    ----------------------------------------------------------------------  */

/*
 * This file contains all definitions and public symbols for
 * the sf firewall.
 *
 * $Id: sf_kernel.h,v 1.13 1995/07/13 14:37:44 roland Rel $
 */

#ifndef _SF_KERNEL_H
#define _SF_KERNEL_H

/*
 *	Which ip routine is calling?
 */

#define SF_STATE_RECEIVE  0
#define SF_STATE_FORWARD  1
#define SF_STATE_TRANSMIT 2

/* macro to convert the return code into the icmp_message_type to be sent */
#define RC_TO_ICMPTYPE(a)	(abs( (a) ) - 1)

/*
 *	Public symbols
 */

extern int sf_fw_chk_pass(struct iphdr *, struct device *, int);
extern int sf_fw_chk_block(struct iphdr *, struct device *, int);
extern int (*sf_fw_chk)(struct iphdr *, struct device *, int);

#endif
